export type CompileOptions = {
    allowBestEffort?: boolean;
    global?: boolean;
    hasIndices?: boolean;
    maxRecursionDepth?: number | null;
    optimize?: boolean;
    target?: "ES2018" | "ES2024" | "ESNext";
};
/**
@typedef {{
  allowBestEffort?: boolean;
  global?: boolean;
  hasIndices?: boolean;
  maxRecursionDepth?: number | null;
  optimize?: boolean;
  target?: keyof Target;
}} CompileOptions
*/
/**
Transpiles an Oniguruma regex pattern and flags to native JS.
@param {string} pattern Oniguruma regex pattern.
@param {import('./tokenize.js').OnigurumaFlags} [flags] Oniguruma flags. Flag `m` is equivalent to JS flag `s`.
@param {CompileOptions} [options]
@returns {{
  pattern: string;
  flags: string;
}}
*/
export function compile(pattern: string, flags?: import("./tokenize.js").OnigurumaFlags, options?: CompileOptions): {
    pattern: string;
    flags: string;
};
/**
Returns a complete set of options, with default values set for options that weren't provided.
@param {CompileOptions} [options]
@returns {Required<CompileOptions>}
*/
export function getOptions(options?: CompileOptions): Required<CompileOptions>;
