import { compile } from './compile.js';
/**
Generates an Oniguruma AST from an Oniguruma pattern and flags.
@param {string} pattern Oniguruma regex pattern.
@param {import('./tokenize.js').OnigurumaFlags} [flags] Oniguruma flags. Flag `m` is equivalent to JS flag `s`.
@returns {import('./parse.js').OnigurumaAst}
*/
export function toOnigurumaAst(pattern: string, flags?: import("./tokenize.js").OnigurumaFlags): import("./parse.js").OnigurumaAst;
/**
Generates a `regex` AST from an Oniguruma pattern and flags.
@param {string} pattern Oniguruma regex pattern.
@param {import('./tokenize.js').OnigurumaFlags} [flags] Oniguruma flags. Flag `m` is equivalent to JS flag `s`.
@returns {import('./transform.js').RegexAst}
*/
export function toRegexAst(pattern: string, flags?: import("./tokenize.js").OnigurumaFlags): import("./transform.js").RegexAst;
/**
Transpiles an Oniguruma regex pattern and flags and returns a native JS RegExp.
@param {string} pattern Oniguruma regex pattern.
@param {import('./tokenize.js').OnigurumaFlags} [flags] Oniguruma flags. Flag `m` is equivalent to JS flag `s`.
@param {import('./compile.js').CompileOptions} [options]
@returns {RegExp}
*/
export function toRegExp(pattern: string, flags?: import("./tokenize.js").OnigurumaFlags, options?: import("./compile.js").CompileOptions): RegExp;
export { compile };
