export type RegexAst = {
    type: "Regex";
    parent: null;
    pattern: any;
    flags: any;
    options: any;
};
/**
@typedef {{
  type: 'Regex';
  parent: null;
  pattern: Object;
  flags: Object;
  options: Object;
}} RegexAst
*/
/**
Transforms an Oniguruma AST in-place to a `regex` AST. Targets `ESNext`, expecting the generator to
then down-convert to the desired JS target version.

A couple edge cases exist where options `allowBestEffort` and `bestEffortTarget` are used:
- `VariableLengthCharacterSet` kind `grapheme` (`\X`): An exact representation would require heavy
  Unicode data; a best-effort approximation requires knowing the target.
- `CharacterSet` kind `posix` with values `graph` and `print`: Their complex exact representations
  are hard to change after the fact in the generator to a best-effort approximation based on
  the target, so produce the appropriate structure here.
@param {import('./parse.js').OnigurumaAst} ast
@param {{
  allowBestEffort?: boolean;
  bestEffortTarget?: keyof Target;
}} [options]
@returns {RegexAst}
*/
export function transform(ast: import("./parse.js").OnigurumaAst, options?: {
    allowBestEffort?: boolean;
    bestEffortTarget?: "ES2018" | "ES2024" | "ESNext";
}): RegexAst;
